<?
/**
 * Writes message to specified log file (or generic.log by default)
 * Returns the datetime of the line on success or false on failure
 * @param string $message
 * @param string [$file]
 * @return string|boolean
 */
function log_file($message, $file = "generic.log")
{
  $date = "[".date("Y-m-d H:i")."] ";
  $file = fopen($file, "a+");

  $message = $date.$message."\n";

  if ($file !== false)
  {
    fwrite($file, $message);
    return $date;
  }
  else
    return false;
}

/**
 * @param string $email
 * @return bool|string
 */
function validateSanitizeEmail($email)
{
  $email = filter_var($email, FILTER_SANITIZE_EMAIL);
  
  $email = filter_var($email, FILTER_VALIDATE_EMAIL);
  
  list($name, $domain) = explode("@", $email);
  
  if (checkdnsrr($domain, "MX"))
    return $email;
  else
    return false;
}

/**
 * @param $string
 * @return String
 */
function csvEncode($string)
{
  $string = str_replace(",", "%21", $string);
  $string = str_replace(";", "%22", $string);
  $string = str_replace("|", "%23", $string);
  $string = str_replace("/", "%24", $string);
  
  return $string;
}

/**
 * @param $string
 * @return String
 */
function csvDecode($string)
{
  $string = str_replace("%21", ",", $string);
  $string = str_replace("%22", ";", $string);
  $string = str_replace("%23", "|", $string);
  $string = str_replace("%24", "/", $string);

  return $string;
}

/**
 * @param $target {String}
 * @param $stringOrList {Array|String}
 * @return String
 */
function insert($target, $stringOrList)
{
  if (is_array($stringOrList))
  {
    foreach ($stringOrList as $key => $value)
    {
      $rpl = "{" . $key . "}";
      $target = str_replace($rpl, $value, $target);
    }
  }
  else
  {
    $target = str_replace("{0}", $stringOrList, $target);
  }
  return $target;
}

function recrmdir($dir)
{
  $files = array_diff(scandir($dir), array('.','..'));
  foreach ($files as $file)
  {
    (is_dir("$dir/$file")) ? recrmdir("$dir/$file") : unlink("$dir/$file");
  }
  return rmdir($dir);
}

/**
 * @param {string} $dir_path
 * @return array
 */
function recursive_dir_scan($dir_path)
{
  $files = array();
  $dir = opendir($dir_path);

  while ($file = readdir($dir))
  {
    if ($file != "." && $file != "..")
    {
      if (is_dir($dir_path . $file))
        $files = array_merge($files, recursive_dir_scan($dir_path . $file . "/"));
      else
      {
        $size = filesize($dir_path.$file);
        array_push($files, array("filename" => $file, "dir" => $dir_path, "path" => $dir_path . $file, "size" => $size));
      }
    }
  }

  return $files;
}

function string_to_hex($str)
{
  $code = dechex(crc32($str));
  $code = substr($code, 0, 6);
  return $code;
}

/**
 * @param ... {mixed}
 * @return array
 */
function array_order_by()
{
  $args = func_get_args();
  $data = array_shift($args);
  foreach ($args as $n => $field) {
    if (is_string($field)) {
      $tmp = array();
      foreach ($data as $key => $row)
        $tmp[$key] = $row[$field];
      $args[$n] = $tmp;
    }
  }
  $args[] = &$data;
  call_user_func_array('array_multisort', $args);
  return array_pop($args);
}

/**
 * @param $var string
 * @return bool
 */
function isEmpty($var)
{
  if (isset($var) && is_string($var) && $var != "")
    return false;
  return true;
}